@@ -200,6 +200,9 @@ void Mod_ResetAll (void)
 	int		i;
 	qmodel_t	*mod;
 
+	//ericw -- free alias model VBOs
+	GLMesh_DeleteVertexBuffers ();
+	
 	for (i=0 , mod=mod_known ; i<mod_numknown ; i++, mod++)
 	{
 		if (!mod->needload) //otherwise Mod_ClearAll() did it already
@@ -531,8 +534,10 @@ void Mod_LoadTextures (lump_t *l)
 					q_snprintf (filename2, sizeof(filename2), "%s_glow", filename);
 					data = Image_LoadImage (filename2, &fwidth, &fheight);
 					if (!data)
+					{
 						q_snprintf (filename2, sizeof(filename2), "%s_luma", filename);
 						data = Image_LoadImage (filename2, &fwidth, &fheight);
+					}
 
 					if (data)
 						tx->fullbright = TexMgr_LoadImage (loadmodel, filename2, fwidth, fheight,
@@ -1193,6 +1198,16 @@ void Mod_LoadFaces (lump_t *l, qboolean bsp2)
 		else if (out->texinfo->texture->name[0] == '*') // warp surface
 		{
 			out->flags |= (SURF_DRAWTURB | SURF_DRAWTILED);
+
+		// detect special liquid types
+			if (!strncmp (out->texinfo->texture->name, "*lava", 5))
+				out->flags |= SURF_DRAWLAVA;
+			else if (!strncmp (out->texinfo->texture->name, "*slime", 6))
+				out->flags |= SURF_DRAWSLIME;
+			else if (!strncmp (out->texinfo->texture->name, "*tele", 5))
+				out->flags |= SURF_DRAWTELE;
+			else out->flags |= SURF_DRAWWATER;
+
 			Mod_PolyForUnlitSurface (out);
 			GL_SubdivideSurface (out);
 		}
